import type { RepairReqVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  repairReqExport = '/eims/repairReq/export',
  repairReqList = '/eims/repairReq/list',
  root = '/eims/repairReq'
}

/**
 * 查询故障报修列表
 * @param query
 * @returns {*}
 */

export function listRepairReq(params?: any) {
  return requestClient.get<RepairReqVO[]>(Api.repairReqList, { params });
}

/**
 * 查询故障报修详细
 * @param repairReqId
 */
export function getRepairReq(repairReqId: ID) {
  return requestClient.get<RepairReqVO>(`${Api.root}/${repairReqId}`);
}

/**
 * 新增故障报修
 * @param data
 */
export function addRepairReq(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改故障报修
 * @param data
 */
export function updateRepairReq(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除故障报修
 * @param repairReqId
 */
export function delRepairReq(repairReqId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${repairReqId}`);
}
/**
 * 导出
 * @param
 */
export function repairReqExport(data: any) {
  return commonExport(Api.repairReqExport, data);
}
